@@ -28,19 +28,10 @@ class TUHEEGArtifactIndex(Index):
         )
 
     def _get_record_metadata(self, file: File) -> Metadata:
-        logging.debug('Add file %s raw metadata to index', file.id)
         meta = file.path.split(sep)
-        raw = Raw(file.id, join(self.path, file.path))
-        return Metadata(
-            file_id=raw.id,
-            duration=raw.open().n_times/raw.open().info['sfreq'],
-            channels_count=raw.open().info['nchan'],
-            channels_reference=meta[0],
-            channels_set=json.dumps(raw.open().info['ch_names']),
-            sampling_frequency=raw.open().info['sfreq'],
-            max_value=raw.open().get_data().max(),
-            min_value=raw.open().get_data().min(),
-        )
+        metadata = super()._get_record_metadata(file)
+        metadata.channels_reference = meta[0]
+        return metadata
 
     def _get_record_events(self, file: File) -> List[Event]:
         logging.debug('Add file %s raw events to index', file.id)
